Learn by Examples
=================

.. toctree::
    notebooks/01Load_xml_measurement_files.ipynb
    notebooks/02Common_DataStore_functions_slice_mean_max_std_resample.ipynb
    notebooks/03Define_sections.ipynb
    notebooks/04Calculate_variance_Stokes.ipynb
    notebooks/07Calibrate_single_ended.ipynb
    notebooks/08Calibrate_double_ended.ipynb
    notebooks/09Import_timeseries.ipynb
    notebooks/10Align_double_ended_measurements.ipynb
    notebooks/11Merge_single_measurements_into_double.ipynb
    notebooks/12Datastore_from_numpy_arrays.ipynb
    notebooks/13Fixed_parameter_calibration.ipynb
    notebooks/14Lossy_splices.ipynb
    notebooks/15Matching_sections.ipynb
    notebooks/16Averaging_temperatures.ipynb
    notebooks/17Temperature_uncertainty_single_ended.ipynb
    notebooks/A2Load_sensornet_files.ipynb
    notebooks/A3Load_ap_sensing_files.ipynb
    notebooks/A4Load_sensortran_files.ipynb
